@@ -460,7 +460,7 @@ function parsePortfolio(data) {
                              //"id": pfoId,
                              "feedLink": pfoFeedLink,
                              //"currency": currency,
-                             "gainPercent": pfoGainPercent,
+                             //"gainPercent": pfoGainPercent,
                              //"rtnYTD": pfoRtnYTD,
                              "excerpt": "-",
                              "num": 0
@@ -470,11 +470,12 @@ function parsePortfolio(data) {
                 model.append({
                              //"idx": i,
                              //"etag": pfoEtag,
+                             "local": 0,
                              "name": pfoName,
                              //"id": pfoId,
                              "feedLink": pfoFeedLink,
                              //"currency": currency,
-                             "gainPercent": pfoGainPercent,
+                             //"gainPercent": pfoGainPercent,
                              //"rtnYTD": pfoRtnYTD,
                              "excerpt": "-",
                              "num": 0
@@ -497,10 +498,22 @@ function parsePortfolio(data) {
             console.log("pfo.rtnYTD="+pfoRtnYTD);
             //*/
         }
-
     //}catch(err) {
     //    addError("Error: " + err);
     //}
+        // Push local portfolio
+        var fileOk = fileHandler.loadPfo();
+
+        if (fileOk==0){
+            model.append({
+                         "local": 1,
+                         "name": fileHandler.localPfoName,
+                         "feedLink": "",
+                         "excerpt": "Locally stored portfolio",
+                         "num": 0
+            });
+        }
+
     waiting.state = "hidden";
 }
 
@@ -508,7 +521,7 @@ function parsePortfolioNum(data, pfoIdx) {
     var posLength = data.childNodes[7].firstChild.nodeValue;
     var symName = new String("");
 
-    for (var i=0; i<(model.count&3); i++) {
+    for (var i=0; i< ((posLength>3) ? 3 : posLength) ; i++) {
         symName += data.childNodes[10+i].childNodes[7].attributes[2].nodeValue + ", ";
     }
 
@@ -803,6 +816,8 @@ function convertExchangeForYahoo (name, exg) {
     else if (exg=="TSXV")             { return (name + "." + "V");  }
     else if (exg=="TSX")              { return (name + "." + "TO"); }
     else if (exg=="LON")              { return (name + "." + "L"); }
+    // Australia
+    else if (exg=="ASX")              { return (name + "." + "AX"); }
     // Asian
     else if (exg=="TPE")              { return (name + "." + "TW"); }
     else if (exg=="HKG")              { return (name + "." + "HK"); }
