@@ -36,6 +36,11 @@ var action = "";
 var tags = "";
 
 var itemsURL = "";
+var gPfoLength;
+
+function returnLength() {
+    return gPfoLength;
+}
 
 function setComponents(mod, pos, wait, err) {
     model   = mod;
@@ -261,7 +266,7 @@ function login(email, password) {
     error.state  = "hidden";
 
     try {
-        waiting.state = "shown";
+        waiting.state = "login";
         var url = "https://www.google.com/accounts/ClientLogin?Email=" + encodeURIComponent(email) + "&Passwd=" + encodeURIComponent(password) + "&service=finance" + "&source=" + encodeURIComponent("stockona");
         doWebRequest("POST", url, 1, parseToken, 0);
     }catch(err) {
@@ -293,8 +298,9 @@ function loadAllPortfolios() {
 
 function loadOnePosition(posFeedLink) {
     // Pull both return and transactions info
-    itemsURL = posFeedLink+"?returns=true&transactions=true";
-    //itemsURL = "http://finance.google.com/finance/feeds/default/portfolios/2/positions?returns=true&transactions=true";
+//    itemsURL = posFeedLink+"?returns=true&transactions=true";
+    itemsURL = posFeedLink+"?returns=true";
+    //itemsURL = "http://finance.google.com/finance/feeds/default/portfolios/2/positions?returns=true";
     console.log(itemsURL);
     loadPosition();
 }
@@ -349,9 +355,9 @@ function loadPosition() {
 function loadQuote(symObj, idx) {
     if (idx >= pModel.count) {
         pModel.append({
-                     "idx":            idx,
-                     "id":             symObj.symId,
-                     "rtnYTD":         symObj.symRtnYTD,
+                     //"idx":            idx,
+                     //"id":             symObj.symId,
+                     //"rtnYTD":         symObj.symRtnYTD,
                      "share":          symObj.symShare,
                      "shareCost":      symObj.shareCost,
                      "shareDayGain":   symObj.shareDayGain,
@@ -394,8 +400,8 @@ function loadQuote(symObj, idx) {
             "shareCost":      symObj.shareCost,
             "shareDayGain":   symObj.shareDayGain,
             "shareValue":     symObj.shareValue,
-            "rtnYTD":         symObj.symRtnYTD,
             "shareGainPercent": symObj.shareGainPercent
+            //"rtnYTD":         symObj.symRtnYTD
         });
     }
 
@@ -439,6 +445,7 @@ function parsePortfolio(data) {
         // <openSearch::totalResults>
         var pfoLength = data.childNodes[8].firstChild.nodeValue;
         //console.log("pfo.length="+pfoLength);
+        gPfoLength = pfoLength;
 
         // <entry>
         for (var i=0; i<pfoLength; i++) {
@@ -498,21 +505,25 @@ function parsePortfolio(data) {
             console.log("pfo.rtnYTD="+pfoRtnYTD);
             //*/
         }
+
     //}catch(err) {
     //    addError("Error: " + err);
     //}
-        // Push local portfolio
-        var fileOk = fileHandler.loadPfo();
+        // Load local portfolio
 
-        if (fileOk==0){
-            model.append({
-                         "local": 1,
-                         "name": fileHandler.localPfoName,
-                         "feedLink": "",
-                         "excerpt": "Locally stored portfolio",
-                         "num": 0
-            });
-        }
+//        var fileOk = fileHandler.loadPfo();
+
+//        if (fileOk==0){
+//            for (var i=0; i < fileHandler.localPfoName.length; i++) {
+//                model.append({
+//                             "local": 1,
+//                             "name": fileHandler.localPfoName[i],
+//                             "feedLink": "",
+//                             "excerpt": fileHandler.localPfoDesc[i],
+//                             "num": fileHandler.localPfoNum[i]
+//                });
+//            }
+//        }
 
     waiting.state = "hidden";
 }
@@ -598,9 +609,10 @@ function parsePosition(data) {
         */
         for (var i=0; i<posLength; i++) {
             // Transaction data
-            var txLength =data.childNodes[10+i].childNodes[5].firstChild.childNodes[6].firstChild.nodeValue;
+            //var txLength =data.childNodes[10+i].childNodes[5].firstChild.childNodes[6].firstChild.nodeValue;
 
             // Catch-ya: when there is tx record available, the first gf transactiondata node becomes the date
+            /*
             for (var j=0; j<txLength; j=j+1) {
                 // Check attribute number
                 var txTxDataAttLength = data.childNodes[10+i].childNodes[5].firstChild.childNodes[8+j].childNodes[5].attributes.length;
@@ -619,6 +631,7 @@ function parsePosition(data) {
                     "txComUnit"     : data.childNodes[10+i].childNodes[5].firstChild.childNodes[8+j].childNodes[5].childNodes[0].firstChild.attributes[1].nodeValue
             };
 
+
 //                console.log("####="+symObj.symName);
 //                console.log("txLength "     +   txLength   );
 //                console.log("txAttLength "  +   txTxDataAttLength);
@@ -629,6 +642,7 @@ function parsePosition(data) {
 //                console.log(" txCom "       +  txObj.txCom      );
 //                console.log(" txComUnit "   +  txObj.txComUnit  );
             }
+            */
 
             var symObj = {
                 //"symId"          : data.childNodes[10+i].childNodes[0].firstChild.nodeValue,
@@ -816,6 +830,8 @@ function convertExchangeForYahoo (name, exg) {
     else if (exg=="TSXV")             { return (name + "." + "V");  }
     else if (exg=="TSX")              { return (name + "." + "TO"); }
     else if (exg=="LON")              { return (name + "." + "L"); }
+    // Australia
+    else if (exg=="ASX")              { return (name + "." + "AX"); }
     // Asian
     else if (exg=="TPE")              { return (name + "." + "TW"); }
     else if (exg=="HKG")              { return (name + "." + "HK"); }
@@ -825,39 +841,9 @@ function convertExchangeForYahoo (name, exg) {
     else                              { return "NULL"; }
 }
 
-function getNodeValue(node, name) {
-    var nodeValue = "";
-    for(var i=0; i<node.childNodes.length; i++) {
-        var nodeName = node.childNodes[i].nodeName;
-        if(nodeName==name) {
-            nodeValue = node.childNodes[i].firstChild.nodeValue;
-        }
-    }
-    return nodeValue;
-}
-
-function formatNumber(data) {
-    // > 1M: Display M
-    // > 10k: Display K
-    var tmp;
-    if (Number(data)>1000000) {
-        tmp = sprintf("%.2f", Number(data)/1000000);
-        return tmp + "m";
-    }
-    else if (Number(data)>10000) {
-        tmp = sprintf("%.2f", Number(data)/10000);
-        return tmp + "k";
-    }
-    else {
-        return sprintf("%.2f", Number(data));
-    }
-}
-
-function removeLinks(original) {
-    var txt = original;
-    txt = txt.replace(/<a /g, "<span ");
-    txt = txt.replace(/<\/a>/g, "</span>");
-    return txt;
+function removeComment(data) {
+    data = data.replace(/\/\//, "");
+    return data;
 }
 
 // function from http://forums.devshed.com/t39065/s84ded709f924610aa44fff827511aba3.html
@@ -955,6 +941,42 @@ function sprintf()
    return str;
 }
 
+/*
+function getNodeValue(node, name) {
+    var nodeValue = "";
+    for(var i=0; i<node.childNodes.length; i++) {
+        var nodeName = node.childNodes[i].nodeName;
+        if(nodeName==name) {
+            nodeValue = node.childNodes[i].firstChild.nodeValue;
+        }
+    }
+    return nodeValue;
+}
+
+function formatNumber(data) {
+    // > 1M: Display M
+    // > 10k: Display K
+    var tmp;
+    if (Number(data)>1000000) {
+        tmp = sprintf("%.2f", Number(data)/1000000);
+        return tmp + "m";
+    }
+    else if (Number(data)>10000) {
+        tmp = sprintf("%.2f", Number(data)/10000);
+        return tmp + "k";
+    }
+    else {
+        return sprintf("%.2f", Number(data));
+    }
+}
+
+function removeLinks(original) {
+    var txt = original;
+    txt = txt.replace(/<a /g, "<span ");
+    txt = txt.replace(/<\/a>/g, "</span>");
+    return txt;
+}
+
 function prettyDate(date){
     try {
         var diff = (((new Date()).getTime() - date.getTime()) / 1000);
@@ -1024,7 +1046,5 @@ function parseDate(stamp)
     }
 }
 
-function removeComment(data) {
-    data = data.replace(/\/\//, "");
-    return data;
-}
+
+*/
